@@ -71,7 +71,15 @@ void ResultsWindow::changeEvent(QEvent *e)
 }
 
 void ResultsWindow::processBarcode(QString barcode) {
-    m_ui->lblResults->setText("Results for '" + barcode + "'");
+    if(barcode.length() > 40) {
+        m_ui->lblResults->setText("Results for '" + barcode.left(40) + "...'");
+    } else {
+        m_ui->lblResults->setText("Results for '" + barcode + "'");
+    }
+
+    // save the barcode text
+    this->barcode_text = QString(barcode);
+
     // let's empty the results container!
     int numberOfWidgets = m_ui->resultsContainer->count();
     for(int i = 0; i<numberOfWidgets;i++) { // iterate through all widgets
@@ -102,3 +110,8 @@ void ResultsWindow::checkPlugins() {
         }
     }
 }
+
+void ResultsWindow::on_pushButton_clicked()
+{
+    QApplication::clipboard()->setText(this->barcode_text, QClipboard::Clipboard);
+}
